act.qc.clean.CleanDataset
=========================

.. currentmodule:: act.qc.clean

.. autoclass:: CleanDataset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CleanDataset.__init__
      ~CleanDataset.clean_arm_qc
      ~CleanDataset.clean_arm_state_variables
      ~CleanDataset.cleanup
      ~CleanDataset.correct_valid_minmax
      ~CleanDataset.get_attr_info
      ~CleanDataset.handle_missing_values
      ~CleanDataset.link_variables
      ~CleanDataset.normalize_assessment
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CleanDataset.matched_qc_variables
   
   